;; base16-measured-light-theme.el -- A base16 colorscheme

;;; Commentary:
;; Base16: (https://github.com/tinted-theming/home)

;;; Authors:
;; Scheme: Measured (https://measured.co)
;; Template: Kaleb Elwert <belak@coded.io>

;;; Code:

(require 'base16-theme)

(defvar base16-measured-light-theme-colors
  '(:base00 "#fdf9f5"
    :base01 "#f9f5f1"
    :base02 "#ffeada"
    :base03 "#5a5a5a"
    :base04 "#404040"
    :base05 "#292929"
    :base06 "#181818"
    :base07 "#000000"
    :base08 "#ac1f35"
    :base09 "#ad5601"
    :base0A "#645a00"
    :base0B "#0c680c"
    :base0C "#01716f"
    :base0D "#0158ad"
    :base0E "#6645c2"
    :base0F "#a81a66")
  "All colors for Base16 Measured Light are defined here.")

;; Define the theme
(deftheme base16-measured-light)

;; Add all the faces to the theme
(base16-theme-define 'base16-measured-light base16-measured-light-theme-colors)

;; Mark the theme as provided
(provide-theme 'base16-measured-light)

(provide 'base16-measured-light-theme)

;;; base16-measured-light-theme.el ends here
