;; base16-swamp-light-theme.el -- A base16 colorscheme

;;; Commentary:
;; Base16: (https://github.com/tinted-theming/home)

;;; Authors:
;; Scheme: Masroof Maindak (https://github.com/masroof-maindak)
;; Template: Kaleb Elwert <belak@coded.io>

;;; Code:

(require 'base16-theme)

(defvar base16-swamp-light-theme-colors
  '(:base00 "#f1e3d1"
    :base01 "#ddcebc"
    :base02 "#c9b9a7"
    :base03 "#b5a492"
    :base04 "#a0907d"
    :base05 "#64513e"
    :base06 "#786653"
    :base07 "#8c7b68"
    :base08 "#d09700"
    :base09 "#64513e"
    :base0A "#993333"
    :base0B "#908d6a"
    :base0C "#d09700"
    :base0D "#bf7979"
    :base0E "#9e5581"
    :base0F "#75858c")
  "All colors for Base16 Swamp Light are defined here.")

;; Define the theme
(deftheme base16-swamp-light)

;; Add all the faces to the theme
(base16-theme-define 'base16-swamp-light base16-swamp-light-theme-colors)

;; Mark the theme as provided
(provide-theme 'base16-swamp-light)

(provide 'base16-swamp-light-theme)

;;; base16-swamp-light-theme.el ends here
