;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "base16-theme" "20260621.406"
  "Collection of themes built on combinations of 16 base colors."
  ()
  :url "https://github.com/tinted-theming/base16-emacs"
  :commit "93b118e5ae7477361d1120db32508cb9756eb145"
  :revdesc "93b118e5ae74"
  :authors '(("Kaleb Elwert" . "belak@coded.io"))
  :maintainers '(("Kaleb Elwert" . "belak@coded.io")))
